import { faInfoCircle, faTimes } from "@fortawesome/free-solid-svg-icons";
import { h } from "@stencil/core";
import { EventBus } from "../../../utils/EventBus";
import { SidePanelSideEnum } from "../../visual/side-panel/side-panel.types";
import { NotificationsFeedEventsEnum } from "./notifications-feed.types";
export class NotificationsFeed {
    constructor() {
        this.isOpen = false;
        this.pendingTransactions = [];
        this.transactionsHistory = [];
        this.eventBus = new EventBus();
        this.closeEventTimeout = null;
        this.handleClose = () => {
            this.isOpen = false;
            this.eventBus.publish(NotificationsFeedEventsEnum.CLOSE_NOTIFICATIONS_FEED);
        };
        this.handleClear = () => {
            this.eventBus.publish(NotificationsFeedEventsEnum.CLEAR_NOTIFICATIONS_FEED_HISTORY);
        };
        this.handleViewAll = () => {
            this.isOpen = true;
        };
    }
    clearTimeouts() {
        if (this.closeEventTimeout) {
            clearTimeout(this.closeEventTimeout);
            this.closeEventTimeout = null;
        }
    }
    disconnectedCallback() {
        this.clearTimeouts();
        this.eventBus.unsubscribe(NotificationsFeedEventsEnum.PENDING_TRANSACTIONS_UPDATE, this.pendingTransactionsUpdate.bind(this));
        this.eventBus.unsubscribe(NotificationsFeedEventsEnum.TRANSACTIONS_HISTORY_UPDATE, this.transactionsHistoryUpdate.bind(this));
        this.eventBus.unsubscribe(NotificationsFeedEventsEnum.OPEN_NOTIFICATIONS_FEED, this.handleViewAll.bind(this));
    }
    async getEventBus() {
        return this.eventBus;
    }
    render() {
        var _a, _b, _c;
        const hasActivity = ((_a = this.transactionsHistory) === null || _a === void 0 ? void 0 : _a.length) > 0;
        const hasPending = ((_b = this.pendingTransactions) === null || _b === void 0 ? void 0 : _b.length) > 0;
        return (h("side-panel", { key: 'beb5a50af755228b50dbb52bd69c56397fa1eeac', isOpen: this.isOpen, side: SidePanelSideEnum.RIGHT, onClose: this.handleClose }, h("div", { key: 'ba6eb7ef12bfe8f9ea6f11fbec264373f56e2d84', class: "feed-content" }, h("div", { key: '80dd63655dec15bc3932dd5c70cf6583ee93f04c', class: "feed-header" }, h("h2", { key: '63cb746bea5a4fb36d4572eeeab34320e71ac33f', class: "feed-title" }, "Notifications Feed"), h("button", { key: 'cac788c5e8a0969445b036507f5208515e507224', class: "close-button", onClick: this.handleClose }, h("fa-icon", { key: '9b87a1f5e2d4418bfd2da971b18e0d879ed95e95', class: "close-icon", icon: faTimes }))), h("div", { key: '316867e8a89cb5c3cd9bc065e23189620fb56d9d', class: "notifications-info" }, h("fa-icon", { key: '2cbf7f6c2a3b00e0e1208e0a12c13b736b28a257', class: "info-icon", icon: faInfoCircle }), "This feed is stored in your browser and will be reset when a new session is started."), hasPending && (h("div", { key: '42d378586071dcb8bca3c9573edb1e1dcef29f45', class: "notifications-container" }, h("div", { key: '3a4d274d820a0a7b8115363a598733e9336d1688', class: "processing-status" }, "Processing..."), (_c = this.pendingTransactions) === null || _c === void 0 ? void 0 :
            _c.map(toast => h("transaction-toast", Object.assign({}, toast))))), h("div", { key: 'b70a528a5e6f9369bcc8cb92707b34b6ab39ce9e', class: "activity-section" }, h("div", { key: 'ab0198e40e7c3d8a0cb8fd808d8ae3c55de836af', class: "activity-header" }, h("h3", { key: '231d6c386e59f7ccd8052755cc34dafe5947de87', class: "activity-title" }, "Activity"), hasActivity && (h("button", { key: '74cec8d1da6b0acf8a11009b61e777e23da81986', class: "clear-button", onClick: this.handleClear }, "Clear"))), h("div", { key: '24d42d3f7707f4b76dc2034c4dce3925bdec9cbc', class: "activity-list" }, hasActivity ? this.transactionsHistory.map(transaction => h("transaction-list-item", { transaction: transaction })) : h("div", { class: "no-activity" }, "No activity to show"))))));
    }
    pendingTransactionsUpdate(payload) {
        this.pendingTransactions = [...payload];
    }
    transactionsHistoryUpdate(payload) {
        this.transactionsHistory = [...payload];
    }
    componentDidLoad() {
        this.eventBus.subscribe(NotificationsFeedEventsEnum.PENDING_TRANSACTIONS_UPDATE, this.pendingTransactionsUpdate.bind(this));
        this.eventBus.subscribe(NotificationsFeedEventsEnum.TRANSACTIONS_HISTORY_UPDATE, this.transactionsHistoryUpdate.bind(this));
        this.eventBus.subscribe(NotificationsFeedEventsEnum.OPEN_NOTIFICATIONS_FEED, this.handleViewAll.bind(this));
    }
    static get is() { return "notifications-feed"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["notifications-feed.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["notifications-feed.css"]
        };
    }
    static get states() {
        return {
            "isOpen": {},
            "pendingTransactions": {},
            "transactionsHistory": {}
        };
    }
    static get methods() {
        return {
            "getEventBus": {
                "complexType": {
                    "signature": "() => Promise<IEventBus>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        },
                        "IEventBus": {
                            "location": "import",
                            "path": "utils/EventBus",
                            "id": "src/utils/EventBus.ts::IEventBus"
                        }
                    },
                    "return": "Promise<IEventBus>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            }
        };
    }
}
//# sourceMappingURL=notifications-feed.js.map
