import { forceUpdate, h } from "@stencil/core";
import { DataTestIdsEnum } from "../../../constants/dataTestIds.enum";
import { EventBus } from "../../../utils/EventBus";
import { SidePanelSideEnum } from "../../visual/side-panel/side-panel.types";
import { PendingTransactionsEventsEnum } from "./pending-transactions-panel.types";
export class PendingTransactionstPanel {
    constructor() {
        this.eventBus = new EventBus();
        this.isOpen = false;
        this.data = {
            isPending: false,
            title: '',
            subtitle: '',
        };
    }
    componentDidLoad() {
        this.eventBus.subscribe(PendingTransactionsEventsEnum.DATA_UPDATE, this.dataUpdate.bind(this));
        this.eventBus.subscribe(PendingTransactionsEventsEnum.OPEN_PENDING_TRANSACTIONS_PANEL, this.handleOpen.bind(this));
        this.eventBus.subscribe(PendingTransactionsEventsEnum.CLOSE_PENDING_TRANSACTIONS, this.onClose.bind(this, { isUserClick: false }));
    }
    disconnectedCallback() {
        this.eventBus.unsubscribe(PendingTransactionsEventsEnum.DATA_UPDATE, this.dataUpdate.bind(this));
        this.eventBus.unsubscribe(PendingTransactionsEventsEnum.OPEN_PENDING_TRANSACTIONS_PANEL, this.handleOpen.bind(this));
        this.eventBus.unsubscribe(PendingTransactionsEventsEnum.CLOSE_PENDING_TRANSACTIONS, this.onClose.bind(this, { isUserClick: false }));
    }
    handleOpen() {
        this.isOpen = true;
    }
    handleClose() {
        this.isOpen = false;
        this.onClose({ isUserClick: true });
    }
    onClose(props = { isUserClick: true }) {
        this.isOpen = false;
        if (props.isUserClick) {
            this.eventBus.publish(PendingTransactionsEventsEnum.CLOSE_PENDING_TRANSACTIONS);
        }
    }
    dataUpdate(payload) {
        if (payload.shouldClose) {
            return this.onClose({ isUserClick: false });
        }
        this.isOpen = true;
        this.data = Object.assign({}, payload);
        forceUpdate(this);
    }
    async getEventBus() {
        return this.eventBus;
    }
    render() {
        return (h("side-panel", { key: '00d663f3ad8385b49d80be1418fbc41cdae0a8df', isOpen: this.isOpen, side: SidePanelSideEnum.RIGHT, panelClassName: "pending-transactions-panel", onClose: this.handleClose.bind(this) }, h("div", { key: '5dda2b56418ceb2997f2c088ca4ce3217283b53b', class: "pending-transactions-content" }, h("div", { key: '70a238cadf378d2c0c922c13e913ee021204406b', class: "pending-transactions-header" }, h("h2", { key: '5831a8602f21c48f289f873aba04a4e7be1e2227', "data-testid": DataTestIdsEnum.pendingTransactionsTitle }, this.data.title), h("h4", { key: 'f0488ae706d4dd7155487720d3d83bfcb1696de2', "data-testid": DataTestIdsEnum.pendingTransactionsSubtitle }, this.data.subtitle)), h("div", { key: 'f3c4149f3c1d8f2244e7041436a7d132df809e19', class: "pending-transactions-body" }, h("button", { key: '478a6888419ea97b8c001be5e9bdca4530b6c462', class: "close-button", onClick: this.handleClose.bind(this) }, "Close")))));
    }
    static get is() { return "pending-transactions-panel"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["pending-transactions-panel.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["pending-transactions-panel.css"]
        };
    }
    static get properties() {
        return {
            "data": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "IPendingTransactionsPanelData",
                    "resolved": "IPendingTransactionsPanelData",
                    "references": {
                        "IPendingTransactionsPanelData": {
                            "location": "import",
                            "path": "./pending-transactions-panel.types",
                            "id": "src/components/functional/pending-transactions-panel/pending-transactions-panel.types.ts::IPendingTransactionsPanelData"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "defaultValue": "{\n    isPending: false,\n    title: '',\n    subtitle: '',\n  }"
            }
        };
    }
    static get states() {
        return {
            "isOpen": {}
        };
    }
    static get methods() {
        return {
            "getEventBus": {
                "complexType": {
                    "signature": "() => Promise<IEventBus>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        },
                        "IEventBus": {
                            "location": "import",
                            "path": "utils/EventBus",
                            "id": "src/utils/EventBus.ts::IEventBus"
                        }
                    },
                    "return": "Promise<IEventBus>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            }
        };
    }
}
//# sourceMappingURL=pending-transactions-panel.js.map
