import { forceUpdate, h } from "@stencil/core";
import { SidePanelSideEnum } from "../../visual/side-panel/side-panel.types";
import { DataTestIdsEnum } from "../../../constants/dataTestIds.enum";
import { WalletConnectEventsEnum } from "./wallet-connect-panel.types";
import { WalletConnectBase } from "./WalletConnectBase";
export class WalletConnectPanel {
    constructor() {
        this.data = {
            wcURI: '',
        };
        this.qrCodeSvg = '';
        this.isOpen = false;
        this.walletConnectBase = new WalletConnectBase(this.data);
    }
    componentDidLoad() {
        this.walletConnectBase.subscribeEventBus(this.getEventBusSubscription());
        this.walletConnectBase.eventBus.subscribe(WalletConnectEventsEnum.OPEN_WALLET_CONNECT_PANEL, this.handleOpen.bind(this));
        this.walletConnectBase.eventBus.subscribe(WalletConnectEventsEnum.CLOSE_WALLET_CONNECT_PANEL, this.onClose.bind(this, { isUserClick: false }));
    }
    disconnectedCallback() {
        this.walletConnectBase.unsubscribeEventBus(this.getEventBusSubscription());
        this.walletConnectBase.eventBus.unsubscribe(WalletConnectEventsEnum.OPEN_WALLET_CONNECT_PANEL, this.handleOpen.bind(this));
        this.walletConnectBase.eventBus.unsubscribe(WalletConnectEventsEnum.CLOSE_WALLET_CONNECT_PANEL, this.onClose.bind(this, { isUserClick: false }));
    }
    handleOpen() {
        this.isOpen = true;
    }
    handleClose() {
        this.isOpen = false;
        this.onClose({ isUserClick: true });
    }
    onClose(props = { isUserClick: true }) {
        this.isOpen = false;
        if (props.isUserClick) {
            this.walletConnectBase.eventBus.publish(WalletConnectEventsEnum.CLOSE_WALLET_CONNECT_PANEL);
        }
    }
    async getEventBus() {
        return this.walletConnectBase.getEventBus();
    }
    getEventBusSubscription() {
        return {
            closeFn: () => this.onClose({ isUserClick: false }),
            forceUpdateFn: () => {
                this.data = this.walletConnectBase.data;
                forceUpdate(this);
            },
        };
    }
    async onDataChange(data) {
        if (data.wcURI) {
            this.qrCodeSvg = await this.walletConnectBase.generateSVG(data.wcURI);
        }
    }
    render() {
        return (h("side-panel", { key: '3e0659b82826620e0c582452ded2d427dab2bfc7', isOpen: this.isOpen, side: SidePanelSideEnum.RIGHT, panelClassName: "wallet-connect-side-panel", onClose: this.handleClose.bind(this) }, h("div", { key: '1272e5056f22a3dd3bb17e827c3698ecfd74ffcf', class: "wallet-connect-container" }, h("div", { key: '516467ca3a6ce970fe3879478325d6662637765f', class: "wallet-connect-header" }, h("h2", { key: '84c4649d0eca333be220db90c33edf7f32f3bb63', "data-testid": DataTestIdsEnum.walletConnetModalTitle }, "xPortal Mobile Wallet"), h("h4", { key: 'db16c0e9f4d90c745c2995b82519518d95d69588', "data-testid": DataTestIdsEnum.walletConnetModalSubtitle }, "Scan this QR code with your app")), h("wallet-connect-body", { key: 'f55b3a4811e48256691f6ce0ad47fd82a8452b20', qrCodeSvg: this.qrCodeSvg }))));
    }
    static get is() { return "wallet-connect-panel"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["wallet-connect-panel.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["wallet-connect-panel.css"]
        };
    }
    static get properties() {
        return {
            "data": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "IWalletConnectPanelData",
                    "resolved": "IWalletConnectPanelData",
                    "references": {
                        "IWalletConnectPanelData": {
                            "location": "import",
                            "path": "./wallet-connect-panel.types",
                            "id": "src/components/functional/wallet-connect-components/wallet-connect-panel.types.ts::IWalletConnectPanelData"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "defaultValue": "{\n    wcURI: '',\n  }"
            }
        };
    }
    static get states() {
        return {
            "qrCodeSvg": {},
            "isOpen": {}
        };
    }
    static get methods() {
        return {
            "getEventBus": {
                "complexType": {
                    "signature": "() => Promise<IEventBus>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        },
                        "IEventBus": {
                            "location": "import",
                            "path": "utils/EventBus",
                            "id": "src/utils/EventBus.ts::IEventBus"
                        }
                    },
                    "return": "Promise<IEventBus>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            }
        };
    }
    static get elementRef() { return "hostElement"; }
    static get watchers() {
        return [{
                "propName": "data",
                "methodName": "onDataChange"
            }];
    }
}
//# sourceMappingURL=wallet-connect-panel.js.map
