import { faArrowLeft } from "@fortawesome/free-solid-svg-icons";
import { h } from "@stencil/core";
import { ProviderTypeEnum } from "../../../types/provider.types";
import { SidePanelSideEnum } from "../side-panel/side-panel.types";
export class UnlockPanel {
    constructor() {
        this.isOpen = false;
        this.allowedProviders = Object.values(ProviderTypeEnum);
        this.isLoggingIn = false;
        this.selectedMethod = null;
        this.anchor = null;
        this.observer = null;
    }
    disconnectedCallback() {
        if (this.observer) {
            this.observer.disconnect();
        }
    }
    observeContainer(element) {
        if (!element) {
            return;
        }
        this.anchor = element;
        if (this.observer) {
            this.observer.disconnect();
        }
        this.observer = new MutationObserver(() => {
            this.isLoggingIn = element.childElementCount > 0;
        });
        this.observer.observe(element, { childList: true, subtree: true });
    }
    handleLogin(provider) {
        this.login.emit({ provider, anchor: this.anchor });
        this.selectedMethod = provider;
    }
    resetLoginState() {
        this.isLoggingIn = false;
        this.selectedMethod = null;
        if (!this.anchor) {
            return;
        }
        while (this.anchor.firstChild) {
            this.anchor.removeChild(this.anchor.firstChild);
        }
    }
    handleClose() {
        this.close.emit();
    }
    render() {
        return (h("side-panel", { key: '43df86980c2851aa74dae21fdcd6978986f48576', isOpen: this.isOpen, side: SidePanelSideEnum.RIGHT, onClose: this.handleClose.bind(this), panelClassName: "unlock-panel" }, h("unlock-header", { key: 'ed6ec3c73b0421edfa28890f4ccd01dd443aa5d9', text: this.isLoggingIn ? `${this.selectedMethod} connect` : 'Connect your wallet', backIcon: this.isLoggingIn ? faArrowLeft : null, onBack: this.resetLoginState.bind(this), onClose: this.handleClose.bind(this) }), h("div", { key: 'a3b9397a9426e4581a348434b008e273cf3ff173', id: "anchor", ref: element => this.observeContainer(element) }), !this.isLoggingIn && (h("div", { key: '598fa74e02c56195e269112b136fa6046745796a', class: "body" }, this.allowedProviders.map(method => (h("provider-button", { type: method, onClick: this.handleLogin.bind(this, method) }))), h("slot", { key: '5760146f0421d6d7215dd4b58f10fe6df072ce0e' })))));
    }
    static get is() { return "unlock-panel"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["unlock-panel.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["unlock-panel.css"]
        };
    }
    static get properties() {
        return {
            "isOpen": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "is-open",
                "reflect": false,
                "defaultValue": "false"
            },
            "allowedProviders": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "ProviderTypeEnum[]",
                    "resolved": "ProviderTypeEnum[]",
                    "references": {
                        "ProviderTypeEnum": {
                            "location": "import",
                            "path": "types/provider.types",
                            "id": "src/types/provider.types.ts::ProviderTypeEnum"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "defaultValue": "Object.values(ProviderTypeEnum)"
            }
        };
    }
    static get states() {
        return {
            "isLoggingIn": {},
            "selectedMethod": {}
        };
    }
    static get events() {
        return [{
                "method": "close",
                "name": "close",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                }
            }, {
                "method": "login",
                "name": "login",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "{ provider: ProviderTypeEnum; anchor?: HTMLElement }",
                    "resolved": "{ provider: ProviderTypeEnum; anchor?: HTMLElement; }",
                    "references": {
                        "ProviderTypeEnum": {
                            "location": "import",
                            "path": "types/provider.types",
                            "id": "src/types/provider.types.ts::ProviderTypeEnum"
                        },
                        "HTMLElement": {
                            "location": "global",
                            "id": "global::HTMLElement"
                        }
                    }
                }
            }];
    }
}
//# sourceMappingURL=unlock-panel.js.map
